package at.xaxa.ledger.ui.category.edit

import android.util.Log
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.ledger.ui.AppViewModelProvider
import at.xaxa.ledger.ui.ButtonDanger
import at.xaxa.ledger.ui.ButtonSuccess
import at.xaxa.ledger.ui.category.iconNames
import at.xaxa.ledger.ui.category.icons



@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun EditCategory(
    onButtonClick: () -> Unit,
    modifier: Modifier = Modifier,
    editCategoryViewModel: EditCategoryViewModel = viewModel(factory = AppViewModelProvider.Factory)
) {
    val category = editCategoryViewModel.categoryUi.category
    var expanded by remember { mutableStateOf(false) } // Controls dropdown visibility
    var selectedIconIndex by remember { mutableIntStateOf(category.icon) }  // Store index of selected icon

    LaunchedEffect(category) {
        selectedIconIndex = category.icon
    }

    /*
    val categories by categoryViewModel.categoryUiState.categories.collectAsState(initial = emptyList())
    val category = categoryViewModel.categoryUi.category
    var expanded by remember { mutableStateOf(false) }*/


    Log.w("vm", category.categoryName.toString())
    Log.w("vm", category.icon.toString())
    Log.w("vm", selectedIconIndex.toString())

    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(16.dp, 0.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Column(
            Modifier.weight(1f)
        ) {
            OutlinedTextField(
                value = category.categoryName,
                onValueChange = { editCategoryViewModel.updateCategory(category.copy(categoryName = it)) },
                label = { Text("Category Name") },
                modifier = Modifier
                    .fillMaxWidth()
            )

            ExposedDropdownMenuBox(
                expanded = expanded,
                onExpandedChange = { expanded = it }
            ) {
                OutlinedTextField(
                    value = iconNames[selectedIconIndex], // Show selected icon name
                    onValueChange = {},
                    label = { Text("Icon") },
                    readOnly = true,
                    leadingIcon = {
                        Icon(
                            imageVector = icons[selectedIconIndex], // Replace with your desired icon
                            contentDescription = "Leading Icon"
                        )
                    },
                    trailingIcon = {
                        ExposedDropdownMenuDefaults.TrailingIcon(expanded = expanded)
                    },
                    modifier = Modifier
                        .menuAnchor()
                        .fillMaxWidth()
                )

                ExposedDropdownMenu(
                    expanded = expanded,
                    onDismissRequest = { expanded = false }
                ) {
                    icons.forEachIndexed { index, icon ->
                        DropdownMenuItem(
                            text = { Text(text = iconNames[index]) }, // Use name from iconNames
                            onClick = {
                                selectedIconIndex = index // Update selected index

                                editCategoryViewModel.updateCategory(category.copy(icon = index))
                                expanded = false
                            },
                            leadingIcon = {
                                Icon(
                                    imageVector = icon,
                                    contentDescription = iconNames[index]
                                )
                            }
                        )
                    }
                }
            }
        }

        Column(
            modifier = Modifier.fillMaxWidth(),
            horizontalAlignment = Alignment.CenterHorizontally // Center buttons horizontally
        ) {
            ButtonDanger(
                modifier = Modifier
                    .padding(bottom = 8.dp),
                "Delete Category",
                onClick = {
                    editCategoryViewModel.deleteEntry()
                    onButtonClick()
                }
            )
            ButtonSuccess(
                modifier = Modifier,
                "Save Category",
                onClick = {
                    editCategoryViewModel.saveCategory()
                    onButtonClick()
                }
            )
        }
    }
}

